@@ -1,6 +1,6 @@
 APP = "apigeecli"
 CMD = "apigee"
-__version__ = "0.36.0"
+__version__ = "0.36.1"
 description = (
     "Apigee Management API command-line interface with multi-factor authentication"
 )
@@ -9,9 +9,14 @@ long_description = (
 
 Getting Help:
 
-    Homepage: https://pypi.org/project/apigeecli/
-    Apigee Product Documentation: https://apidocs.apigee.com/management/apis
-    The Apigee Management API command-line interface documentation: https://mdelotavo.github.io/apigee-cli/
+    Homepage:
+        https://pypi.org/project/apigeecli/
+
+    Apigee Product Documentation:
+        https://apidocs.apigee.com/management/apis
+
+    The Apigee Management API command-line interface documentation:
+        https://mdelotavo.github.io/apigee-cli/
     """
 )
 
